from signxml import XMLSigner, XMLVerifier

signer = XMLSigner()
verifier = XMLVerifier()

def sign(tree, key, cert, **kwargs):
    return signer.sign(tree, key=key, cert=cert, **kwargs)

def verify(tree, **kwargs):
    return verifier.verify(tree, **kwargs).signed_xml is not None



import pkgutil
import inspect

sepa_messages = {}

# Loop over all message groups
for loader, name, is_pkg in pkgutil.walk_packages(__path__):
    if '.' in name:
        continue

    # Load message group module
    module = loader.find_module(name).load_module(name)

    # Export messages from message group
    sepa_messages[name] = module.sepa_messages



import os
from lxml import etree
from .messages import sepa_messages

# Export validator message types
for group_name, group in sepa_messages.items():
    for name, message in group.items():
        schema_name = message.standard + '.xsd'
        globals()[name] = schema_name
        globals()[message.name] = schema_name

def get_schema(schema_name):
    return etree.XMLSchema(etree.parse(os.path.join(os.path.dirname(__file__), 'schemas', schema_name)))

def validate(schema_name, tree):
    return get_schema(schema_name).validate(tree)

def validate_or_error(schema_name, tree):
    return get_schema(schema_name).assertValid(tree)



from sepa.definitions.payment import payment_group_header, payment

# PAIN.008.001.07 - Customer Direct Debit Initiation v7
standard = 'pain.008.001.07'
name = 'customer_direct_debit_initiation'
definition = {
    '_namespaces': {
        None: 'urn:iso:std:iso:20022:tech:xsd:pain.008.001.07',
        'xs': 'http://www.w3.org/2001/XMLSchema'
    },
    '_self': 'CstmrDrctDbtInitn',
    '_sorting': ['GrpHdr', 'PmtInf', 'SplmtryData'],
    'group_header': payment_group_header('GrpHdr'),
    'payments': [payment('PmtInf')],
    'supplementary_data': ['SplmtryData']
}
